==> kubernetes-model-core-4.13.2-sources.jar: io/fabric8/kubernetes/api/model/EndpointPortBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class EndpointPortBuilder extends EndpointPortFluentImpl<EndpointPortBuilder> implements VisitableBuilder<EndpointPort,EndpointPortBuilder> {

    EndpointPortFluent<?> fluent;
    Boolean validationEnabled;

    public EndpointPortBuilder() { 
        this(true);
    }


    public EndpointPortBuilder(Boolean validationEnabled) { 
        this(new EndpointPort(), validationEnabled);
    }


    public EndpointPortBuilder(EndpointPortFluent<?> fluent) { 
        this(fluent, true);
    }


    public EndpointPortBuilder(EndpointPortFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new EndpointPort(), validationEnabled);
    }


    public EndpointPortBuilder(EndpointPortFluent<?> fluent,EndpointPort instance) { 
        this(fluent, instance, true);
    }


    public EndpointPortBuilder(EndpointPortFluent<?> fluent,EndpointPort instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withAppProtocol(instance.getAppProtocol()); 
        fluent.withName(instance.getName()); 
        fluent.withPort(instance.getPort()); 
        fluent.withProtocol(instance.getProtocol()); 
        this.validationEnabled = validationEnabled; 
    }


    public EndpointPortBuilder(EndpointPort instance) { 
        this(instance,true);
    }


    public EndpointPortBuilder(EndpointPort instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withAppProtocol(instance.getAppProtocol()); 
        this.withName(instance.getName()); 
        this.withPort(instance.getPort()); 
        this.withProtocol(instance.getProtocol()); 
        this.validationEnabled = validationEnabled; 
    }


    public EndpointPort build() {
        EndpointPort buildable = new EndpointPort(fluent.getAppProtocol(),fluent.getName(),fluent.getPort(),fluent.getProtocol());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        EndpointPortBuilder that = (EndpointPortBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-core-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/EndpointPortBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class EndpointPortBuilder extends EndpointPortFluentImpl<EndpointPortBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<EndpointPort,EndpointPortBuilder> {

    EndpointPortFluent<?> fluent;
    Boolean validationEnabled;

    public EndpointPortBuilder() {
        this(true);
    }

    public EndpointPortBuilder(Boolean validationEnabled) {
        this(new EndpointPort(), validationEnabled);
    }

    public EndpointPortBuilder(EndpointPortFluent<?> fluent) {
        this(fluent, true);
    }

    public EndpointPortBuilder(EndpointPortFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new EndpointPort(), validationEnabled);
    }

    public EndpointPortBuilder(EndpointPortFluent<?> fluent,EndpointPort instance) {
        this(fluent, instance, true);
    }

    public EndpointPortBuilder(EndpointPortFluent<?> fluent,EndpointPort instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withAppProtocol(instance.getAppProtocol()); 
        fluent.withName(instance.getName()); 
        fluent.withPort(instance.getPort()); 
        fluent.withProtocol(instance.getProtocol()); 
        this.validationEnabled = validationEnabled; 
    }

    public EndpointPortBuilder(EndpointPort instance) {
        this(instance,true);
    }

    public EndpointPortBuilder(EndpointPort instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withAppProtocol(instance.getAppProtocol()); 
        this.withName(instance.getName()); 
        this.withPort(instance.getPort()); 
        this.withProtocol(instance.getProtocol()); 
        this.validationEnabled = validationEnabled; 
    }

    public EndpointPort build() {
        EndpointPort buildable = new EndpointPort(fluent.getAppProtocol(),fluent.getName(),fluent.getPort(),fluent.getProtocol());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        EndpointPortBuilder that = (EndpointPortBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
